@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v2.1.1
+v2.1.2
 dpt_runtime/exceptions/traced_exception_mixin.py
 """
 
@@ -42,7 +42,7 @@ streams.
     """
 Additional __slots__ used for inherited classes.
     """
-    __slots__ = [ ]
+    __slots__ = ( )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
