@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v2.1.1
+v2.1.2
 dpt_runtime/io/byte_buffer.py
 """
 
@@ -41,7 +41,7 @@ safe.
 
     # pylint: disable=invalid-name
 
-    __slots__ = [ "__weakref__", "buffer", "buffer_file", "_buffer_reset", "buffer_size", "file_threshold" ]
+    __slots__ = ( "__weakref__", "buffer", "buffer_file", "_buffer_reset", "buffer_size", "file_threshold" )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
