@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v2.1.1
+v2.1.2
 dpt_runtime/io/descriptor_selector.py
 """
 
@@ -39,7 +39,7 @@ the same time.
 Additional poll signals to be handled.
     """
 
-    __slots__ = [ "_poller", "_selectors", "_selectors_polled" ]
+    __slots__ = ( "_poller", "_selectors", "_selectors_polled" )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
