@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v2.1.1
+v2.1.2
 dpt_runtime/io/socket_reader.py
 """
 
@@ -37,7 +37,7 @@ operations from blocking and non-blocking sockets.
              Mozilla Public License, v. 2.0
     """
 
-    __slots__ = [ "__weakref__", "socket", "_timeout" ]
+    __slots__ = ( "__weakref__", "socket", "_timeout" )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
