@@ -13,7 +13,7 @@ obtain one at http://mozilla.org/MPL/2.0/.
 ----------------------------------------------------------------------------
 https://www.direct-netware.de/redirect?licenses;mpl2
 ----------------------------------------------------------------------------
-v2.1.1
+v2.1.2
 dpt_runtime/iterator.py
 """
 
@@ -36,7 +36,7 @@ newer.
 
     # pylint: disable=abstract-method
 
-    __slots__ = [ ]
+    __slots__ = ( )
     """
 python.org: __slots__ reserves space for the declared variables and prevents
 the automatic creation of __dict__ and __weakref__ for each instance.
